#! /usr/bin/env python3

# #################################################################################### #
#                                                                                      #
# actionc: Task "Action" and Profile "condition" dictionary                                  #
#                                                                                      #
#  Provide the master lookup for a given <code>nnn</code> xml statement                      #
#  level 1 key = the code (nnn, above)                                                       #
#   numargs subkey = the maximum number of argn xml lines in the action                      #
#      if it = 99, then this is a referral to another entry, which is identified in 'args'   #
#   args subkey = the specific arg number  keys with a 's' or 'e' are Profile conditions     #
#        ...'e'=event, 's'=state, 't'=task                                                   #
#   display subkey = the name to output - required                                           #
#   reqargs subkey = the requirement arg statement numbers for evaluation - optional         #
#   evalargs subkey = formula for evaluation - optional                                      #
#      'some_string:' for str or int xml values                                              #
#      ['', 'e', 'some_string'] for boolean: 1 = display string, 0 = no display - optl       #
#                                                                                      #
#      ['some_string:', 'l', 'lookup-code] for actiont dictionary lookup for specific code   #
# GNU General Public License v3.0                                                      #
# Permissions of this strong copyleft license are conditioned on making available      #
# complete source code of licensed works and modifications, which include larger works #
# using a licensed work, under the same license. Copyright and license notices must be #
# preserved. Contributors provide an express grant of patent rights.                   #
# #################################################################################### #

action_codes = {
    "1000e": {
        "numargs": 0,
        "args": ["0"],
        "types": ["Int"],
        "display": "Display Unlocked",
        "reqargs": ["0"],
        "evalargs": [["Priority:", "l", "4s"]],
    },
    "1000s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Plugin",
        "reqargs": [],
        "evalargs": [],
    },
    "1000t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Plugin",
        "reqargs": [],
        "evalargs": [],
    },
    "100s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Airplane Mode",
        "reqargs": [],
        "evalargs": [],
    },
    "100t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "ConditionList"],
        "display": "Search",
        "reqargs": ["0", "1"],
        "evalargs": ["Number:", ["", "e", "Info"]],
    },
    "101t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Take Photo",
        "reqargs": [],
        "evalargs": [],
    },
    "102t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Open File",
        "reqargs": [],
        "evalargs": [],
    },
    "103s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Light Level",
        "reqargs": ["0"],
        "evalargs": [],
    },
    "104s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Pressure",
        "reqargs": [],
        "evalargs": [],
    },
    "104t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Browse URL",
        "reqargs": [],
        "evalargs": [],
    },
    # Reference entry for plugins
    "1040876951t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Str", "Str", "Int", "Int"],
        "display": "AutoInput UI Query",
        "reqargs": ["0", "3", "4"],
        "evalargs": ["", "Timeout:", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "105s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Media Button",
        "reqargs": [],
        "evalargs": [],
    },
    "105t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Str"],
        "display": "Set Clipboard",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Text:", ["", "e", ", Add"], "Image:"],
    },
    "106s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Magnetic Field",
        "reqargs": [],
        "evalargs": [],
    },
    "107s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Missed Call",
        "reqargs": [],
        "evalargs": [],
    },
    "107361459t": {"redirect": ["1040876951t"], "display": "AutoInput Actions V2"},
    "109t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Set Wallpaper",
        "reqargs": [],
        "evalargs": [],
    },
    "1099157652t": {"redirect": ["1040876951t"], "display": "AutoTools Json Write"},
    "10s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Power",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "10s"]],
    },
    "110s": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Int", "Int", "Int", "Int", "Int"],
        "display": "Mobile Network",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            ["", "e", "2G"],
            ["", "e", "3G"],
            ["", "e", "3G-HSPA"],
            ["", "e", "4G"],
            ["", "e", "5G"],
            [", Active:", "l", "160"],
        ],
    },
    "111t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Compose MMS",
        "reqargs": [],
        "evalargs": [],
    },
    "112t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Run SL4A Script",
        "reqargs": [],
        "evalargs": [],
    },
    "1120274117t": {"redirect": ["1040876951t"], "display": "Locus Map"},
    "1132319851t": {"redirect": ["1040876951t"], "display": "AutoSheets Add Sheet"},
    "1133159835e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoShare Process Text",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "1138194991s": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoWear State",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", "Structure Output (JSON (etc)"]],
    },
    "1138588429t": {"redirect": ["1040876951t"], "display": "Join Send Query"},
    "113t": {"numargs": 0, "args": [], "types": [], "display": "WiFi Tether"},
    "114t": {"numargs": 0, "args": [], "types": [], "display": "USB Tether"},
    "1150542767e": {"redirect": ["1040876951t"], "display": "Tap Tap Plugin"},
    "116t": {"numargs": 0, "args": [], "types": [], "display": "HTTP Post"},
    "1164968315t": {"redirect": ["1040876951t"], "display": "AutoSpotify Play Media"},
    "1165325195t": {"redirect": ["1040876951t"], "display": "AutoTools Web Screen"},
    "117t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "HTTP Head",
        "reqargs": [],
        "evalargs": [],
    },
    "117240295t": {"redirect": ["1040876951t"], "display": "AutoWear Input"},
    "118t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "HTTP Get",
        "reqargs": [],
        "evalargs": [],
    },
    "1186637727t": {"redirect": ["1040876951t"], "display": "KWGT Kustom Widget Maker"},
    "119t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Int", "Str", "Str", "Int", "Str"],
        "display": "Open Map",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            ["Mode:", "l", "119"],
            ", Address:",
            ", Lat, Long:",
            ", Zoom:",
            ", Label:",
        ],
    },
    "120s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Orientation",
        "reqargs": ["0"],
        "evalargs": [["Is:", "l", "120s"]],
    },
    "122375409t": {"redirect": ["1040876951t"], "display": "AutoWeb Web Services"},
    "122s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Display Orientation",
        "reqargs": ["0"],
        "evalargs": [["Is:", "l", "122s"]],
    },
    "123s": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Int", "Int", "Str", "Str", "Str", "Int", "Int"],
        "display": "Display State",
        "reqargs": ["0"],
        "evalargs": [["", "e", "switch_set"]],
    },
    "123t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Int", "Int", "Str", "Str", "Str", "Int", "Int"],
        "display": "Run Shell",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Command:",
            ", Timeout:",
            ["", "e", ", Use Root"],
            ", Store Output In:",
            ", Store Errors In:",
            ", Timeout:",
            ["", "e", ", Use Task Set0tings"],
        ],
    },
    "1246578872t": {"redirect": ["1040876951t"], "display": "AutoWear Notification"},
    "124t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Remount",
        "reqargs": [],
        "evalargs": [],
    },
    "1250249549t": {"redirect": ["1040876951t"], "display": "AutoInput Screen Off/On"},
    "125s": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Str"],
        "display": "Proximity Sensor",
        "reqargs": [],
        "evalargs": [],
    },
    "125t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Str"],
        "display": "Compose Email",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Recipient(s):", ", Subject:", ", Message:"],
    },
    "126t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Int", "Int", "Int", "Str", "ConditionList"],
        "display": "Return",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            "Value:",
            ["", "e", ", Stop"],
            ["", "e", ", Local Variable Passthrough"],
            ["", "e", ", Replace On Passthrough"],
            ", Limit Passthrough To:",
        ],
    },
    "129t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Str", "Int", "Int", "ConditionList"],
        "display": "JavaScriptLet",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["Code:", ", Libraries:", ["", "e", ", Auto Exit"], ", Timeout:"],
    },
    "12s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "HDMI Plugged",
        "reqargs": [],
        "evalargs": [],
    },
    "1304982781t": {"redirect": ["1040876951t"], "display": "AutoTools Dialog"},
    "130t": {
        "numargs": 12,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        "types": [
            "Str",
            "Int",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "display": "Perform Task",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        "evalargs": [
            "Name:",
            ", Priority:",
            ", Parameter 1:",
            ", Parameter 2:",
            ", Return Value Variable:",
            ["", "e", ", Stop"],
            ["", "e", ", Local Variable Passthrough"],
            ", Limit Passthrough To:",
            ["", "e", ", Reset Return Variable"],
            ["", "e", ", Allow Overwrite Variables"],
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    },
    "131t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Int"],
        "display": "JavaScript",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Path:", ", Libraries:", ["", "e", ", Auto Exit"], ", Timeout:"],
    },
    "1339942270t": {"redirect": ["1040876951t"], "display": "SharpTools Thing"},
    "133t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Set Tasker Pref",
        "reqargs": ["0", "1"],
        "evalargs": [["Set:", "l", "133"], ", Value:"],
    },
    "1339291165t": {"redirect": ["1040876951t"], "display": "AutoWeb Download"},
    "1344888481e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "Notification Listener",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "134e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Card Mounted",
        "reqargs": [],
        "evalargs": [],
    },
    "134t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Query Action",
        "reqargs": ["0"],
        "evalargs": ["Action:"],
    },
    "135e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Card Unmounted",
        "reqargs": [],
        "evalargs": [],
    },
    "135s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Auto-Sync",
        "reqargs": [],
        "evalargs": [],
    },
    "135t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Str", "ConditionList"],
        "display": "Go To",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Set:", "l", "135"], ", Number:", ", Label:"],
    },
    "136e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Card Removed",
        "reqargs": [],
        "evalargs": [],
    },
    "136s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "VPN Connected",
        "reqargs": [],
        "evalargs": [],
    },
    "136t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Sound Effects",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "137t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "ConditionList"],
        "display": "Stop",
        "reqargs": ["0", "1"],
        "evalargs": [["", "e", "Stop"], ", Task:"],
    },
    "138t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Img"],
        "display": "Set Tasker Icon",
        "reqargs": ["0"],
        "evalargs": ["Icon:"],
    },
    "139t": {"numargs": 0, "args": [], "types": [], "display": "Disable (Tasker)"},
    "140618776t": {"redirect": ["1040876951t"], "display": "AutoWear Toast"},
    "140s": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Battery Level",
        "reqargs": ["0", "1"],
        "evalargs": ["From:", ", To:"],
    },
    "140t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Change Icon Set",
        "reqargs": ["0", "1"],
        "evalargs": ["Old:", ", New:"],
    },
    "1410790256t": {"redirect": ["1040876951t"], "display": "AutoWear Floating Icon"},
    "141s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Battery Temperature",
        "reqargs": [],
        "evalargs": [],
    },
    "1411074191t": {"redirect": ["1040876951t"], "display": "AutoSheets Add Rows"},
    "142s": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Profile Active",
        "reqargs": ["0"],
        "evalargs": ["Name:"],
    },
    "142t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Edit Task",
        "reqargs": ["0", "1"],
        "evalargs": ["Task:", ", Action:"],
    },
    "143s": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Task Running",
        "reqargs": ["0"],
        "evalargs": ["Name:"],
    },
    "143t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Edit Scene",
        "reqargs": ["0", "1"],
        "evalargs": ["Scene Name:", ", Element:"],
    },
    "144741820t": {
        "redirect": ["1040876951t"],
        "display": "AutoNotification Hide Notification Icons",
    },
    "1446679033t": {"redirect": ["1040876951t"], "display": "AutoTools Time"},
    "1446874931t": {"redirect": ["1040876951t"], "display": "AutoTools Json Read"},
    "1447159672t": {"redirect": ["1040876951t"], "display": "AutoTools Text"},
    "1447244736t": {"redirect": ["1040876951t"], "display": "AutoTools Action Wait"},
    "145s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Signal Strength",
        "reqargs": [],
        "evalargs": [],
    },
    "1452528931t": {"redirect": ["1040876951t"], "display": "AutoContacts Query 2.0"},
    "1461810131t": {"redirect": ["1040876951t"], "display": "AutoSheets Update Cells"},
    "147s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Unread Text",
        "reqargs": [],
        "evalargs": [],
    },
    "147t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Show Prefs",
        "reqargs": ["0"],
        "evalargs": [["Section:", "l", "147"]],
    },
    "148s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Pen Out",
        "reqargs": [],
        "evalargs": [],
    },
    "148t": {"numargs": 0, "args": [], "types": [], "display": "Show Runlog"},
    "1482108003t": {"redirect": ["1040876951t"], "display": "AutoSpotify Player State"},
    "149s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Pen Menu",
        "reqargs": [],
        "evalargs": [],
    },
    "14s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Power Save Mode",
        "reqargs": [],
        "evalargs": [],
    },
    "1508929357t": {"redirect": ["1040876951t"], "display": "AutoTools Array"},
    "150s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "USB Connected",
        "reqargs": ["0"],
        "evalargs": [["Is:", "l", "150s"]],
    },
    "150t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Keyguard",
        "reqargs": [],
        "evalargs": [],
    },
    "1520257414e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoNotification Intercept",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "152t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Img"],
        "display": "Set Widget Icon",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ", Icon:"],
    },
    "153t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Str"],
        "display": "Import Data",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "153"], ["Source:", "l", "153a"], ", Variable:"],
    },
    "154s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Active User",
        "reqargs": [],
        "evalargs": [],
    },
    "155t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Set Widget Label",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ", Label:"],
    },
    "1563355455t": {
        "redirect": ["1040876951t"],
        "display": "AutoNotification Buttons Notification",
    },
    "1563799945t": {"redirect": ["1040876951t"], "display": "Secure Settings"},
    "156t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "Str"],
        "display": "MIDI Play",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            ["Format:", "l", "156"],
            ["Locality:", "l", "156a"],
            ", Best Timing:",
            ", Score:",
        ],
    },
    "157t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Quick Setting Add",
        "reqargs": [],
        "evalargs": [],
    },
    "158t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Quick Setting Remove",
        "reqargs": [],
        "evalargs": [],
    },
    "159t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "ConditionList"],
        "display": "Profile Status",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ["Set:", "l", "switch_set"]],
    },
    "15t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Str", "Str"],
        "display": "Lock",
        "reqargs": ["2", "3", "4", "5", "6"],
        "evalargs": [
            ["", "e", "Allow Cancel"],
            ["", "e", "Remember Till Off"],
            ["", "e", "Full Screen"],
            ", Background Image:",
            ", Layout:",
        ],
    },
    "160s": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Str", "Int"],
        "display": "Wifi Connected",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["SSID:", ", MAC:", ", IP", ["Active:", "l", "160"]],
    },
    "1600958131t": {
        "redirect": ["1040876951t"],
        "display": "AutoBubbles Create Bubble",
    },
    "161s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Ethernet Connect",
        "reqargs": [],
        "evalargs": [],
    },
    "161t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Str", "Str"],
        "display": "Setup App Shortcuts",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["Task:", ", Task:", ", Task:", ", Task:"],
    },
    "1620773086t": {"redirect": ["1040876951t"], "display": "SharpTools A Thing"},
    "162t": {
        "numargs": 13,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        "types": [
            "Int",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
        ],
        "display": "Setup Quick Setting Tile",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        "evalargs": [
            ["Number:", "l", "162"],
            ", Task:",
            [", Status:", "l", "162a"],
            ["", "e", ", Can Use On Locked Device"],
            ", Long Click Task:",
            ", Double Click Task:",
            ", Subtitle:",
            ", Icon:",
            ", Label:",
            ", Command:",
            ", Long Click Command:",
            ", Double Click Command:",
            ", Command Prefix:",
        ],
    },
    "1643249237t": {"redirect": ["1040876951t"], "display": "Tools & AmazFit"},
    "1644316156t": {"redirect": ["1040876951t"], "display": "AutoNotification Reply"},
    "1646792910t": {
        "redirect": ["1040876951t"],
        "display": "AutoTools Secure Settings",
    },
    "165s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["ConditionList"],
        "display": "Variable Value",
        "reqargs": [],
        "evalargs": [],
    },
    "165t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "Str"],
        "display": "Cancel Alarm",
        "reqargs": ["0", "1"],
        "evalargs": [["Mode:", "l", "165"], ", Minutes:"],
    },
    "166160670t": {
        "redirect": ["1040876951t"],
        "display": "AutoVoice Natural Language",
    },
    "1664218170e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoVoice Natural Language",
        "reqargs": ["3"],
        "evalargs": [["", "e", ", Structure Output (JSON, etc)"]],
    },
    "1668911626e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "Join",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "166t": {"numargs": 0, "args": [], "types": [], "display": "Show Alarms"},
    "1677547919t": {"redirect": ["1040876951t"], "display": "AutoNotification Actions"},
    "1687767515t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoInput Modes",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "1691829355e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "SharpTools Thing",
        "reqargs": ["0"],
        "evalargs": [""],
    },
    "16s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Device Idle",
        "reqargs": [],
        "evalargs": [],
    },
    "16t": {"numargs": 0, "args": [], "types": [], "display": "System Lock"},
    "170s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Wifi Near",
        "reqargs": [],
        "evalargs": [],
    },
    "171109731t": {"redirect": ["1040876951t"], "display": "AutoWeb Authentication"},
    "171t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Beep",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Frequency:",
            ", Duration:",
            ", Amplitude",
            ["Stream:", "l", "171"],
        ],
    },
    "172t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "Int"],
        "display": "Morse",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            "Text:",
            ", Frequency:",
            ", Speed:",
            ", Amplitude:",
            [", Stream:", "l", "171"],
        ],
    },
    "1732635924t": {"redirect": ["1040876951t"], "display": "AutoInput Action"},
    "173t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "App"],
        "display": "Network Access",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "173"]],
    },
    "175s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Dreaming",
        "reqargs": [],
        "evalargs": [],
    },
    "175t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Power Mode",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "175"]],
    },
    "1754437993t": {"redirect": ["1040876951t"], "display": "AutoVoice Recognition"},
    "176t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Take Screenshot",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ["", "e", ", Insert In Gallery"]],
    },
    "177t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Haptic Feedback",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "1788518030e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoInput Key",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "1795842217t": {"redirect": ["1040876951t"], "display": "AutoLaunch"},
    "180s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Temperature",
        "reqargs": [],
        "evalargs": [],
    },
    "1804737413t": {"redirect": ["1040876951t"], "display": "AutoWear Secure Settings"},
    "1810865467t": {"redirect": ["1040876951t"], "display": "AutoSheets Get Data"},
    "1810891651t": {"redirect": ["1040876951t"], "display": "AutoSheets Get Cell"},
    "1825107102e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoNotification",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "182s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Heart Rate",
        "reqargs": [],
        "evalargs": [],
    },
    "1830656901t": {"redirect": ["1040876951t"], "display": "AutoWear List Screens"},
    "1830829821t": {"redirect": ["1040876951t"], "display": "AutoWear 4 Screen"},
    "185s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Humidity",
        "reqargs": [],
        "evalargs": [],
    },
    "185t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Filter Image",
        "reqargs": ["0", "1"],
        "evalargs": [["Mode:", "l", "185"], ", Threshold:"],
    },
    "1861978578e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoWear Command/Command Filter",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "186s": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Str", "Str", "Int", "Str", "ConditionList"],
        "display": "Custom Setting",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            ["Test:", "l", "235"],
            ", Name:",
            ", Value:",
            ["", "e", "Use Root"],
            ", Read Setting To:",
        ],
    },
    "187t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Int"],
        "display": "Save Image",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            "File:",
            ", Image Quality:",
            ["", "e", ", Delete From Memory After"],
        ],
    },
    "188s": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Img", "Int", "Int"],
        "display": "Dark Mode",
        "reqargs": [],
        "evalargs": [],
    },
    "188t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Img", "Int", "Int"],
        "display": "Load Image",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            "Source:",
            ", Max Width or Height:",
            ["", "e", ", Respect EXIF Orientation"],
        ],
    },
    "18927444e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoApps Command",
        "reqargs": ["3"],
        "evalargs": [["", "e", ", Structure Output (JSON, etc)"]],
    },
    "189t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "Int"],
        "display": "Crop Image",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "From Left (%):",
            ", From Right (%):",
            ", From Top (%):",
            ", From Bottom (%):",
        ],
    },
    "18t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["App", "Int"],
        "display": "Kill App",
        "reqargs": ["0", "1"],
        "evalargs": [["a", "", "App:"], ["", "e", "Use Root"]],
    },
    "190s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Any Sensor",
        "reqargs": [],
        "evalargs": [],
    },
    "190t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Flip Image",
        "reqargs": ["0"],
        "evalargs": [["Direction:", "l", "190"]],
    },
    "1910383148t": {"redirect": ["1040876951t"], "display": "AutoTools Regex"},
    "1912522764t": {"redirect": ["1040876951t"], "display": "AutoTools Toast"},
    "191971507t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Str", "Str", "Int", "Int"],
        "display": "AutoWear ADB Wifi",
        "reqargs": ["3"],
        "evalargs": [["", "e", ", Structure Output (JSON, etc)"]],
    },
    "191t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Rotate Image",
        "reqargs": ["0", "1"],
        "evalargs": [["Direction:", "l", "191"], [", Degrees:", "l", "191a"]],
    },
    "192s": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Str"],
        "display": "Matter Light",
        "reqargs": ["1"],
        "evalargs": ["Device IDs/Names:"],
    },
    "192t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Int"],
        "display": "Play Ringtone",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Direction:", "l", "192"], ", Sound:", [", Stream:", "l", "171"]],
    },
    "193t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Resize Image",
        "reqargs": ["0", "1"],
        "evalargs": ["Width:", ", Height:"],
    },
    "194s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Work Profile",
        "reqargs": [],
        "evalargs": [],
    },
    "194t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Str"],
        "display": "Test Scene",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Name:", [", Test:", "l", "194"], ", Store Result In:"],
    },
    "1957670352t": {"redirect": ["1040876951t"], "display": "AutoWear App"},
    "1957681000e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoInput Gesture",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "195s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "NFC Status",
        "reqargs": [],
        "evalargs": [],
    },
    "195t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Str"],
        "display": "Test Element",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Scene Name:",
            ", Element:",
            [", Test:", "l", "195"],
            ", Store Result In:",
        ],
    },
    "197t": {"numargs": 0, "args": [], "types": [], "display": "Developer Settings"},
    "198t": {"numargs": 0, "args": [], "types": [], "display": "Device Info Settings"},
    "199t": {"numargs": 0, "args": [], "types": [], "display": "Add Account Settings"},
    "199558826t": {"redirect": ["1040876951t"], "display": "TouchTask Gestures"},
    "2000e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["App", "Str"],
        "display": "Notification Click",
        "reqargs": ["0", "1"],
        "evalargs": ["Owner Application:", ", Title:"],
    },
    "2003e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Missed Call",
        "reqargs": [],
        "evalargs": [],
    },
    "2005e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "SMS Success",
        "reqargs": [],
        "evalargs": [],
    },
    "200t": {"numargs": 0, "args": [], "types": [], "display": "All Settings"},
    "2010e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "SMS Failure",
        "reqargs": [],
        "evalargs": [],
    },
    "201e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["App", "Str", "Str", "Str"],
        "display": "Assistance Request",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["App:", ", URL:", ", Texts:", ", Extras:", [", Priority:", "4s"]],
    },
    "201t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Airplane Mode Settings",
    },
    "2010186613t": {
        "redirect": ["1040876951t"],
        "display": "AutoSheets Delete Cell Content",
    },
    "202t": {"numargs": 0, "args": [], "types": [], "display": "APN Settings"},
    "2022280279t": {"redirect": ["1040876951t"], "display": "AutoNotification Media"},
    "203e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Battery Changed",
        "reqargs": ["0"],
        "evalargs": [["Priority:", "l", "4s"]],
    },
    "203t": {"numargs": 0, "args": [], "types": [], "display": "Date Settings"},
    "2046367074t": {"redirect": ["1040876951t"], "display": "AutoNotification Cancel"},
    "2041559229t": {"redirect": ["1040876951t"], "display": "AutoSpotify Playlists"},
    "204t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Internal Storage Settings",
    },
    "2050e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Quick Setting Clicked",
        "reqargs": [],
        "evalargs": [],
    },
    "205e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Battery Full",
        "reqargs": [],
        "evalargs": [],
    },
    "2051074546t": {
        "redirect": ["1040876951t"],
        "display": "AutoSpotify Control Media",
    },
    "206e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Battery Overheating",
        "reqargs": [],
        "evalargs": [],
    },
    "206t": {"numargs": 0, "args": [], "types": [], "display": "Wireless Settings"},
    "2075e": {
        "numargs": 2,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Custom Setting",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "235"], ", Name:", ", Value:"],
    },
    "2076e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "NFC Tag",
        "reqargs": ["0", "1"],
        "evalargs": ["ID:", ", Content:"],
    },
    "2077e": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Bundle"],
        "display": "Secondary App Opened",
        "reqargs": [],
        "evalargs": [],
    },
    "2078e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Str"],
        "display": "App Changed",
        "reqargs": ["1"],
        "evalargs": ["Package:"],
    },
    "2079e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Str"],
        "display": "Volume Long Press",
        "reqargs": ["0", "1"],
        "evalargs": [["Type:", "l", "2079e"], ", Additional Time:"],
    },
    "2080e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "ConditionList"],
        "display": "BT Connected",
        "reqargs": ["1", "2"],
        "evalargs": ["Name:", ", Address:"],
    },
    "2081e": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Bundle", "Str", "Str", "Str", "Str", "Int"],
        "display": "Music Track Changed",
        "reqargs": ["1", "2", "3", "4", "5"],
        "evalargs": [
            "Track:",
            ", Album:",
            ", Artist",
            ", Package:",
            [", Type:", "l", "2081e"],
        ],
    },
    "2083e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Significant Motion",
        "reqargs": [],
        "evalargs": [],
    },
    "2084e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Alarm Changed",
        "reqargs": [],
        "evalargs": [],
    },
    "2085e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "Logcat Entry",
        "reqargs": ["1", "2", "3"],
        "evalargs": ["Component:", ", Filter:", ["", "e", ", Grep Filter"]],
    },
    "2088e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Any Sensor",
        "reqargs": [],
        "evalargs": [],
    },
    "2089e": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Bundle", "Int", "Str", "Str", "Str", "Int", "Int", "Str"],
        "display": "HTTP Request",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Port:",
            ", Method:",
            ", Path:",
            ", Quick Response",
            ", Timeout:",
            ["", "e", ", Only On Wifi"],
            ", Network Name/MAC Address:",
        ],
    },
    "208e": {
        "numargs": 0,
        "args": 0,
        "types": [],
        "display": "Display On",
        "reqargs": ["0"],
        "evalargs": [["Priority:", "l", "4s"]],
    },
    "208t": {"numargs": 0, "args": [], "types": [], "display": "Location Settings"},
    "2091e": {
        "numargs": 6,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "Logcat Entry",
        "reqargs": ["1", "2", "3"],
        "evalargs": ["Component:", ", Filter:", ["", "e", ", Grep Filter"]],
    },
    "2092e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Power Menu Shown",
        "reqargs": [],
        "evalargs": [],
    },
    "2093e": {
        "numargs": 1,
        "args": ["0"],
        "types": ["App", "Str"],
        "display": "Assistant Action",
        "reqargs": ["0"],
        "evalargs": ["Command:"],
    },
    "2094e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Call Screened",
        "reqargs": [],
        "evalargs": [],
    },
    "2095e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Str"],
        "display": "Tick",
        "reqargs": ["1"],
        "evalargs": ["Interval (ms):"],
    },
    "2096e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Int", "Int", "Int"],
        "display": "Sleeping",
        "reqargs": ["1", "2", "3"],
        "evalargs": ["Minimum Confidence:", ", Maximum Light:", ", Maximum Motion:"],
    },
    "20t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["App", "Str", "Int", "Int", "ConditionList"],
        "display": "Launch App",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            ["a", "", "App:"],
            ", Data:",
            ["", "e", "Exclude From Recent Apps"],
            ["", "e", "Always Start New Copy"],
            ["if"],
        ],
    },
    "210e": {
        "numargs": 0,
        "args": 0,
        "types": [],
        "display": "Display Off",
        "reqargs": ["0"],
        "evalargs": [["Priority:", "l", "4s"]],
    },
    "210t": {"numargs": 0, "args": [], "types": [], "display": "Input Method Settings"},
    "211t": {"numargs": 0, "args": [], "types": [], "display": "Sync Settings"},
    "211707263t": {"redirect": ["1040876951t"], "display": "Global Actions"},
    "211905330t": {"redirect": ["1040876951t"], "display": "AutoContacts"},
    "2114100406t": {"redirect": ["1040876951t"], "display": "AutoLaunch Query"},
    "212t": {"numargs": 0, "args": [], "types": [], "display": "WiFi IP Settings"},
    "2132875086t": {
        "redirect": ["1040876951t"],
        "display": "AutoSheets Delete Rows/Columns",
    },
    "214t": {"numargs": 0, "args": [], "types": [], "display": "Wireless Settings"},
    "2142731215t": {
        "redirect": ["1040876951t"],
        "display": "AutoSheets Duplicate Sheet",
    },
    "215e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Button: Camera",
        "reqargs": [],
        "evalargs": [],
    },
    "216e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Button: Long Search",
        "reqargs": [],
        "evalargs": [],
    },
    "216t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "ConditionList"],
        "display": "App Settings",
        "reqargs": ["0"],
        "evalargs": ["App"],
    },
    "218t": {"numargs": 0, "args": [], "types": [], "display": "Bluetooth Settings"},
    "219t": {"numargs": 0, "args": [], "types": [], "display": "Quick Settings"},
    "220e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "File Moved",
        "reqargs": [],
        "evalargs": [],
    },
    "220t": {"numargs": 0, "args": [], "types": [], "display": "Mobile Data Settings"},
    "222e": {
        "numargs": 0,
        "args": 0,
        "types": [],
        "display": "File Modified",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ", Event:"],
    },
    "222t": {"numargs": 0, "args": [], "types": [], "display": "Display Settings"},
    "224e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "File Closed",
        "reqargs": [],
        "evalargs": [],
    },
    "224t": {"numargs": 0, "args": [], "types": [], "display": "Locale Settings"},
    "226e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "File Opened",
        "reqargs": [],
        "evalargs": [],
    },
    "226t": {"numargs": 0, "args": [], "types": [], "display": "App Manager Settings"},
    "227t": {"numargs": 0, "args": [], "types": [], "display": "Memory Card Settings"},
    "228e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "File Deleted",
        "reqargs": [],
        "evalargs": [],
    },
    "228t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Network Operator Settings",
    },
    "229t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Quick Launch Settings",
        "reqargs": [],
        "evalargs": [],
    },
    "22t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Load Last App",
        "reqargs": [],
        "evalargs": [],
    },
    "230e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "File Attribute Change",
        "reqargs": [],
        "evalargs": [],
    },
    "230t": {"numargs": 0, "args": [], "types": [], "display": "Security Settings"},
    "231t": {"numargs": 0, "args": [], "types": [], "display": "Search Settings"},
    "232t": {"numargs": 0, "args": [], "types": [], "display": "Sound Settings"},
    "234244923t": {"redirect": ["1040876951t"], "display": "AutoInput Unlock Screen"},
    "234t": {"numargs": 0, "args": [], "types": [], "display": "Dictionary Settings"},
    "235t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Str", "Str", "Int", "Str", "ConditionList"],
        "display": "Custom Settings",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            ["Test:", "l", "235"],
            ", Name:",
            ", Value:",
            ["", "e", "Use Root"],
            ", Read Setting To:",
        ],
    },
    "236t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Accessibility Settings",
    },
    "237t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Notification Listener Settings",
    },
    "238t": {"numargs": 0, "args": [], "types": [], "display": "Privacy Settings"},
    "239t": {"numargs": 0, "args": [], "types": [], "display": "Print Settings"},
    "24081025t": {"redirect": ["1040876951t"], "display": "AutoNotification Snooze"},
    "244t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Toggle Split Screen",
        "reqargs": [],
        "evalargs": [],
    },
    "245t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Back Button",
        "reqargs": [],
        "evalargs": [],
    },
    "246t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Long Power Button",
        "reqargs": [],
        "evalargs": [],
    },
    "247t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Show Recents",
        "reqargs": [],
        "evalargs": [],
    },
    "248t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Turn Off",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ["", "e", "Dim"], ["", "e", ", Lock"]],
    },
    "249t": {"numargs": 0, "args": [], "types": [], "display": "System Screenshot"},
    "250t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Compose SMS",
        "reqargs": ["0", "1"],
        "evalargs": ["Recipient(s):", "Message:"],
    },
    "251t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Battery Settings",
        "reqargs": [],
        "evalargs": [],
    },
    "252t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["App"],
        "display": "Set SMS App",
        "reqargs": ["0"],
        "evalargs": ["App:"],
    },
    "254t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Speakerphone",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "256t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Vibrate On Ringer",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "257t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Power Usage Settings",
        "reqargs": [],
        "evalargs": [],
    },
    "258t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Vibrate On Notify",
        "reqargs": [],
        "evalargs": [],
    },
    "259t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Notification Pulse",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "25t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Go Home",
        "reqargs": [],
        "evalargs": [],
    },
    "260559060t": {"redirect": ["1040876951t"], "display": "AutoNotification Block"},
    "263029931t": {"redirect": ["1040876951t"], "display": "AutoInput Unlock Screen"},
    "268157305t": {"redirect": ["1040876951t"], "display": "AutoNotification Tiles"},
    "294t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "ConditionList"],
        "display": "Bluetooth",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "295t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Bluetooth ID",
        "reqargs": ["0"],
        "evalargs": ["Name:"],
    },
    "296t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Bluetooth Voice",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "2e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Phone Offhook",
        "reqargs": [],
        "evalargs": [],
    },
    "2s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Mobile Data Settings",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "3000e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Gesture",
        "reqargs": [],
        "evalargs": [],
    },
    "3001e": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Shake",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            ["Axis:", "l", "3001e"],
            ["Sensitivity:", "l", "3001ea"],
            ["Duration:", "l", "3001eb"],
        ],
    },
    "300e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Date Set",
        "reqargs": [],
        "evalargs": [],
    },
    "300t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Anchor",
        "reqargs": ["0"],
        "evalargs": ["Label"],
    },
    "301t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Mic Mute",
        "reqargs": [],
        "evalargs": [],
    },
    "302e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Time/Date Set",
        "reqargs": [],
        "evalargs": [],
    },
    "303e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Timer Change",
        "reqargs": [],
        "evalargs": [],
    },
    "303t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Alarm Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "304e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Timezone Set",
        "reqargs": [],
        "evalargs": [],
    },
    "304t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Ringer Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "3050e": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Variable Set",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Variable:", ", Value:", ["", "e", ", User Variables Only"]],
    },
    "305e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Alarm Clock",
        "reqargs": [],
        "evalargs": [],
    },
    "305t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "ConditionList"],
        "display": "Notification Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "3060e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Variable Cleared",
        "reqargs": [],
        "evalargs": [],
    },
    "306e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Alarm Done",
        "reqargs": [],
        "evalargs": [],
    },
    "306t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "In-Call Volume",
        "reqargs": [],
        "evalargs": [],
    },
    "3071e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Zoom Click",
        "reqargs": [],
        "evalargs": [],
    },
    "307e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Monitor Start",
        "reqargs": [],
        "evalargs": [],
    },
    "307t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "ConditionList"],
        "display": "Media Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "308t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "System Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "309e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Steps Taken",
        "reqargs": [],
        "evalargs": [],
    },
    "309t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "DTMF Volume",
        "reqargs": [],
        "evalargs": [],
    },
    "30s": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Headset Plugged",
        "reqargs": ["0"],
        "evalargs": [["Type:", "l", "30s"]],
    },
    "30t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Wait",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": ["MS:", ", Seconds:", ", Minutes:", ", Hours:", ", Days:"],
    },
    "310t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Vibrate Mode",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "310"]],
    },
    "311t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "BT Voice Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "312t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Int", "Int", "Int", "Int", "Str", "Str", "Bundle", "ConditionList"],
        "display": "Do Not Disturb",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "312"]],
    },
    "313t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "ConditionList"],
        "display": "Sound Mode",
        "reqargs": ["0", "1"],
        "evalargs": [["Mode:", "l", "313"], ["", "e", ", Ignore DND"]],
    },
    "314t": {
        "numargs": 10,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "types": ["Int", "Str", "Str", "Str", "Str", "Int", "Str", "Int", "Int", "Int"],
        "display": "Authentication Dialog",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "evalargs": [
            ["Type:", "l", "314"],
            ", Title:",
            ", Subtitle:",
            ", Description:",
            ", Cancel Button Text:",
            ", Number of Attempts:",
            ", Read Result Into:",
            ", Timeout (Seconds):",
            ["", "e", ", Confirmation Required"],
            ["", "e", ", Device Credentials Allowed"],
        ],
    },
    "316t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Str"],
        "display": "Display Size",
        "reqargs": ["0", "1"],
        "evalargs": [["Size:", "l", "316"], ", Manual:"],
    },
    "317t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Bundle"],
        "display": "NFC",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "318t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Force Rotation",
        "reqargs": ["0", "1"],
        "evalargs": [
            ["Mode:", "l", "318"],
            ["", "e", ", Alternative Method (Check Help)"],
        ],
    },
    "319692633t": {"redirect": ["1040876951t"], "display": "AutoShare Process Text"},
    "319t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Ask Permissions",
        "reqargs": ["0", "1"],
        "evalargs": ["Required Permissions:", ", Prompt If Not Granted:"],
    },
    "320t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Str", "Str", "Str"],
        "display": "Ping",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            ", Host:",
            ", Number:",
            ", Average Result Variable:",
            ", Min Result Variable:",
            ", Max Result Variable:",
        ],
    },
    "321t": {
        "numargs": 9,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "types": ["Bundle", "Str", "Str", "Str", "Str", "Str", "Int", "Int", "Str"],
        "display": "GD Upload",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8"],
        "evalargs": [
            "Google Drive/Account:",
            ", Data/File:",
            ", Remote File Name:",
            ", Remote Folder:",
            ", Content Description:",
            ["", "e", ", Overwrite If Exists"],
            ["", "e", ", Publicly Share File"],
            ", Mime Type:",
        ],
    },
    "322t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Data Backup",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            "Path:",
            ", Google Drive Account:",
            ["", "e", ", Include User Vars/Prefs"],
        ],
    },
    "323t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Airplane Radios",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            ["", "e", "Bluetooth"],
            ["", "e", ", Cell"],
            ["", "e", ", NFC"],
            ["", "e", ", Wifi"],
            ["", "e", ", Wimax"],
        ],
    },
    "324t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Bundle", "Str", "Int", "Int", "Str", "Str"],
        "display": "GD List",
        "reqargs": ["1", "2", "3", "5"],
        "evalargs": [
            "Google Drive Account:",
            [", Type:", "l", "324"],
            [", Files or Folders:", "l", "324a"],
            ", Query:",
        ],
    },
    "325t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Bundle", "Str", "Int", "Int", "Str", "Str", "Str", "Str"],
        "display": "GD Trash",
        "reqargs": ["1", "2", "3", "4", "5", "6"],
        "evalargs": [
            "Google Drive Account:",
            [", Trash Value:", "l", "325"],
            [", Type:", "l", "325a"],
            ", File ID:",
            ", Path:",
            ", Remote File Name:",
        ],
    },
    "326t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Bundle", "Str", "Int", "Str", "Str", "Str", "Str"],
        "display": "GD Download",
        "reqargs": ["1", "2", "3", "4", "5", "6"],
        "evalargs": [
            "Google Drive Account:",
            [", Type:", "l", "325a"],
            ", File ID:",
            ", Remote Folder:",
            ", Remote File Name:",
            ", Local Path:",
        ],
    },
    "327t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Bundle", "Str", "Int"],
        "display": "GD Sign In",
        "reqargs": ["1", "2"],
        "evalargs": ["Google Drive Account:", ["", "e", ", Full Access"]],
    },
    "328t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Int", "Int"],
        "display": "Keyboard",
        "reqargs": ["1", "2", "3"],
        "evalargs": [
            "Input",
            ", Time Between Inputs:",
            ["", "e", ", Don't Restore Keyboard"],
        ],
    },
    "329t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Str"],
        "display": "Navigation Bar",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Left:", "Center:", "Right:"],
    },
    "330t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Bundle", "Str", "Str"],
        "display": "NFC Tag",
        "reqargs": ["1", "2"],
        "evalargs": ["Payload To Write:", ", Payload Type:"],
    },
    "331t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Auto-Sync",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "332t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "GPS",
        "reqargs": [],
        "evalargs": [],
    },
    "333t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Bundle"],
        "display": "Airplane Mode",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "334t": {
        "numargs": 9,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Int", "Str", "Str", "Int"],
        "display": "Say WaveNet",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Test/SSML:",
            ", Voice:",
            [", Type:", "l", "171"],
            ", Pitch:",
            ", Speed:",
            ["", "e", ", Continue Task Immediately"],
            ", File:",
            ", Override API Key:",
            ["", "e", ", Respect Audio Focus"],
        ],
    },
    "335t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Str", "Str", "Int", "Int"],
        "display": "App Info",
        "reqargs": ["1", "2", "3", "4"],
        "evalargs": [
            "Package/App Name:",
            ", Ignore Packages:",
            ["", "e", ", Ignore Unlaunchable Apps"],
            ["", "e", ", Get All Details"],
        ],
    },
    "337t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Notification Settings",
        "reqargs": ["0", "1"],
        "evalargs": ["Package:", ", Category:"],
    },
    "338t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Str"],
        "display": "Notification Category Info",
        "reqargs": ["1"],
        "evalargs": ["Category:"],
    },
    "339t": {
        "numargs": 14,
        "args": [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
        ],
        "types": [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "display": "HTTP Request",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        "evalargs": [
            ["Method:", "l", "339"],
            ", URL:",
            ", Headers:",
            ", Query Parameters:",
            ", Body:",
            ", File To Send:",
            ", File/Directory To Save With Output:",
            ", Timeout:",
            ["", "e", ", Trust Any Certificate"],
            ["", "e", ", Automatically Follow Redirects"],
            ["", "e", ", Use Cookies"],
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    },
    "340t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Int", "Str", "Int"],
        "display": "Bluetooth Connection",
        "reqargs": ["1", "2", "3"],
        "evalargs": [["Action:", "l", "340"], ", Device:", ", Timeout:"],
    },
    "341t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test Net",
        "reqargs": ["0", "2"],
        "evalargs": [["Type:", "l", "341"], ", Store Result In:"],
    },
    "342t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Str", "Str", "Int", "Int", "ConditionList"],
        "display": "Test File",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            ["Type:", "l", "342"],
            ", Data:",
            ", Store Result In:",
            ["", "e", ", Use Root"],
        ],
    },
    "343t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test Media",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "343"], ", Data:", ", Store Result In:"],
    },
    "344636446t": {
        "redirect": ["1040876951t"],
        "display": "AutoVoice Trigger Alexa Routine",
    },
    "344t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test App",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "344"], ", Data:", ", Store Result In:"],
    },
    "345t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test Variable",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "345"], ", Data:", ", Store Results In:"],
    },
    "346t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test Phone",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "346"], ", Data:", ", Store Result In:"],
    },
    "347t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Str", "Str", "ConditionList"],
        "display": "Test Tasker",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "347"], ", Data:", ", Store Result In:"],
    },
    "34829087e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "Tools & AmazFit",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "348t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test Display",
        "reqargs": ["0", "1"],
        "evalargs": [["Type:", "l", "348"], ", Store Result In:"],
    },
    "349t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "Test System",
        "reqargs": ["0", "1"],
        "evalargs": [["Type:", "l", "349"], ", Store Result In:"],
    },
    "351t": {
        "numargs": 11,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        "types": [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
        ],
        "display": "HTTP Auth",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        "evalargs": [
            ["Method:", "l", "351"],
            ", Client ID:",
            ", Client Secret:",
            ", Endpoint To Get Code:",
            ", Endpoint To Get Refresh Token:",
            ", Scopes:",
            ["", "e", "Force Re-Authentication"],
            ", Timeout:",
            ", Username:",
            ", Password:",
        ],
    },
    "354t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Str", "ConditionList"],
        "display": "Array Set",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Variable Array:", ", Values:", ", Splitter:"],
    },
    "355t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Str", "Int", "ConditionList"],
        "display": "Array Push",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Variable Array:",
            ", Position:",
            ", Value:",
            ["", "e", ", Fill Spaces"],
        ],
    },
    "356t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Str", "ConditionList"],
        "display": "Array Pop",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Variable Array:", ", Position:", ", To Var:"],
    },
    "357t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Array Clear",
        "reqargs": ["0"],
        "evalargs": ["Variable Array:"],
    },
    "358t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Int", "Str", "Int"],
        "display": "Bluetooth Info",
        "reqargs": ["1", "2", "3"],
        "evalargs": [["Type:", "l", "358"], ", Device:", ", Timeout:"],
    },
    "35t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Wait Until",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [["if"], "MS:", ", Seconds:", ", Minutes:", ", Hours:", ", Days:"],
    },
    "360t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Bundle", "Str", "Str", "Str", "Int", "Str", "Int", "Int"],
        "display": "Input Dialog",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Title:",
            ", Text:",
            ", Default Input:",
            ", Close After (Seconds):",
            ", Input Type:",
            ["", "e", ", Use HTML"],
            ["", "e", ", Pre-Select Input"],
        ],
    },
    "361t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Bundle"],
        "display": "Dark Mode",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "362t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Set Assistant",
        "reqargs": ["0"],
        "evalargs": ["Assistant:"],
    },
    "363t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Str"],
        "display": "Mobile Network Type",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "364t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Int"],
        "display": "Text Next Alarm",
        "reqargs": ["1"],
        "evalargs": ["Minutes Difference:"],
    },
    "365t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Bundle", "Str", "ConditionList"],
        "display": "Tasker Function",
        "reqargs": ["1"],
        "evalargs": ["Function:"],
    },
    "366t": {
        "numargs": 10,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "types": [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Int",
        ],
        "display": "Get Location V2",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "evalargs": [
            "Timeout (Seconds):",
            ", Minimum Accuracy (meters):",
            ", Speed (meters/second):",
            ", Altitude (meters):",
            ", Near Location:",
            ["", "e", ", Enable Location If Needed"],
            ["", "e", ", Last Location If Timeout"],
            ", Min Speed Accuracy (m/s):",
            ["", "e", ", Force High Accuracy"],
        ],
    },
    "367t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Bundle"],
        "display": "Camera",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "368t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Str", "Int", "Str", "Int"],
        "display": "Pick Location",
        "reqargs": ["1", "2", "3", "4"],
        "evalargs": [
            "Title:",
            ["", "e", ", Select Radius"],
            ", Initial Location:",
            [", Set:", "l", "368"],
        ],
    },
    "369t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "ConditionList"],
        "display": "Array Process",
        "reqargs": ["0", "1"],
        "evalargs": ["Variable Array:", [", Type:", "l", "369"]],
    },
    "370t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Str"],
        "display": "Shortcut",
        "reqargs": ["0"],
        "evalargs": ["Shortcut:"],
    },
    "371t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Astrid",
        "reqargs": [],
        "evalargs": [],
    },
    "372t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Str"],
        "display": "Sensor Info",
        "reqargs": ["1"],
        "evalargs": ["Type:"],
    },
    "373t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Int", "Int"],
        "display": "Test Sensor",
        "reqargs": ["1", "2", "3"],
        "evalargs": [
            "Type:",
            ", Timeout (Seconds):",
            ["", "e", ", Convert Orientation"],
        ],
    },
    "374t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Bundle", "Int", "Str", "Int", "Str", "Str", "Str", "Str"],
        "display": "Screen Capture",
        "reqargs": ["1", "2", "3", "4", "5", "6"],
        "evalargs": [
            ["Type:", "l", "374"],
            ", Output File:",
            ["", "e", ", Sound"],
            ", Video Encoder:",
            ", Resolution:",
            ", Video Bitrate:",
        ],
    },
    "375t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "ADB Wifi",
        "reqargs": [],
        "evalargs": [],
    },
    "376t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Str"],
        "display": "Share File",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "File:",
            ", Mime Type:",
            ["", "e", ", Show Chooser Dialog"],
            ", Chooser Dialog Title:",
        ],
    },
    "377t": {
        "numargs": 11,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        "types": [
            "Bundle",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "ConditionList",
        ],
        "display": "Text/Image Dialog",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "evalargs": [
            "Title:",
            ", Text:",
            ", Button 1:",
            ", Button 2:",
            ", Button 3:",
            ", Close After (Seconds):",
            ["", "e", ", Use HTML"],
            ", Image:",
            ", Max Width or Height:",
        ],
    },
    "378t": {
        "numargs": 15,
        "args": [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        "types": [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Str",
            "ConditionList",
        ],
        "display": "List Dialog",
        "reqargs": ["1", "2", "3", "4", "6", "7", "8", "9", "10", "11", "12", "13"],
        "evalargs": [
            ["Mode:", "l", "378"],
            ", Title:",
            ", Items:",
            ", Long Click Task:",
            ", Button 1:",
            ", Button 2:",
            ", Button 3:",
            ", Close After (Seconds):",
            ["", "e", ", Use HTML"],
            ", First Visible Index:",
            ["", "e", ", Hide Filter"],
            ", Text:",
        ],
    },
    "37s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["ConditionList"],
        "display": "Variable Set",
        "reqargs": [],
        "evalargs": [],
    },
    "37t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["ConditionList"],
        "display": "If",
        "reqargs": ["if"],
        "evalargs": [""],
    },
    "380t": {
        "numargs": 10,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "types": [
            "Bundle",
            "Str",
            "Str",
            "Str",
            "Int",
            "Str",
            "Str",
            "Str",
            "Int",
            "Str",
        ],
        "display": "HTTP Response",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8"],
        "evalargs": [
            "Request ID:",
            ", Status Code:",
            ", Headers:",
            ["Type:", "l", "380"],
            "",
            ", File:",
            ", Mime Type:",
            ["", "e", ", File Inline"],
        ],
    },
    "381t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Str", "Str", "Str", "Int"],
        "display": "Contact Via App",
        "reqargs": ["0", "1"],
        "evalargs": ["Contact:", ", App:"],
    },
    "383t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Settings Panel",
        "reqargs": ["0"],
        "evalargs": [["Contact:", "l", "383"]],
    },
    "384t": {
        "numargs": 15,
        "args": [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        "types": [
            "Bundle",
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
        ],
        "display": "Device Control (Power Menu Action)",
        "reqargs": [
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        "evalargs": [
            "ID:",
            [", Action:", "l", "384"],
            [", Type:", "l", "384a"],
            ", Title:",
            ", Subtitle:",
            ", Icon:",
            ", Command:",
            ", Active:",
            ", Range Min:",
            ", Range Max:",
            ", Range Current:",
            "Range Step:",
            ", Range Format:",
            ["", "e", ", Can Use On Locked Device"],
        ],
    },
    "385t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Command",
        "reqargs": ["0"],
        "evalargs": ["Command:"],
    },
    "386t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Bundle", "Int", "Int", "Int", "Int", "Int"],
        "display": "Call Screening",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            ["ID:", "l", "386"],
            ["", "e", ", Skip Call Log"],
            ["", "e", ", Skip Notification"],
        ],
    },
    "387t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Accessibility Volume",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Level:", ["", "e", ", Display"], ["", "e", ", Sound"]],
    },
    "388543774t": {
        "redirect": ["1040876951t"],
        "display": "AutoSheets Insert Empty Rows/Columns",
    },
    "389t": {
        "numargs": 10,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "types": [
            "Bundle",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "display": "Multiple Variables Set",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Names:",
            ", Variable Name Splitter:",
            ", Values:",
            ", Values Splitter:",
            ["", "e", ", Do Maths"],
            ["", "e", ", Keep Existing"],
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    },
    "38t": {"numargs": 0, "args": [], "types": [], "display": "End If"},
    "390t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Bundle", "Str", "Str", "Str", "Str", "Int"],
        "display": "Pick Input Dialog",
        "reqargs": ["1", "2", "3", "4", "5"],
        "evalargs": [
            "Type:",
            ", Title:",
            ", Text:",
            ", Default Input:",
            ", Close After (Seconds):",
        ],
    },
    "391t": {
        "numargs": 12,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        "types": [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Int",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "display": "Progress Dialog",
        "reqargs": ["1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "evalargs": [
            ["Action:", "l", "391"],
            ", Title:",
            ", Text:",
            [", Type:", "l", "391a"],
            ", Animation Images:",
            ", Animation Tint:",
            ", Frame Duration:",
            ", Progress:",
            ", Max:",
        ],
    },
    "392t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Bundle", "Str", "Str"],
        "display": "Set Variable Structure",
        "reqargs": ["1", "2"],
        "evalargs": ["Name:", ", Structure Type:"],
    },
    "393t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Bundle", "Str", "Int", "Str", "Str", "Str", "Str"],
        "display": "Array Merge",
        "reqargs": ["1", "2", "3", "4", "5", "6"],
        "evalargs": [
            "Names:",
            [", Title:", "l", "393"],
            ", Joiner:",
            ", Format:",
            ", Output:",
            ", Join Output:",
        ],
    },
    "394t": {
        "numargs": 13,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        "types": [
            "Bundle",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Str",
            "ConditionList",
        ],
        "display": "Parse/Format DateTime",
        "reqargs": ["1", "2", "3", "4", "5", "7", "8", "9", "10", "11"],
        "evalargs": [
            ["Input Type:", "l", "394"],
            ", Input:",
            ", Input Format:",
            ", Input Separator:",
            ", Output Format:",
            ", Formatted Value Names:",
            ["", "e", ", Get All Details"],
            ["", "e", ", Do Maths"],
            [", Output Offset Type:", "l", "394a"],
            ", Output Offset:",
        ],
    },
    "395t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "JD Status",
        "reqargs": [],
        "evalargs": [],
    },
    "396t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Int", "Str", "Str", "Str"],
        "display": "Simple Match/Regex",
        "reqargs": ["1", "2", "3"],
        "evalargs": [["Type:", "l", "396"], ", Text:", ", Match Pattern/Regex:"],
    },
    "397t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Bundle", "Int"],
        "display": "Get Material You Colors",
        "reqargs": ["1"],
        "evalargs": [["", "e", "Output Hashtags"]],
    },
    "398t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Connect To WiFi",
        "reqargs": ["0"],
        "evalargs": ["SSID:"],
    },
    "399t": {
        "numargs": 10,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "types": [
            "Bundle",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Str",
        ],
        "display": "Variable Map",
        "reqargs": ["1", "2", "3", "4", "5", "7", "8", "9"],
        "evalargs": [
            "Input:",
            ", Input Minimum:",
            ", Input Maximum:",
            ", Output Minimum:",
            ", Output Maximum:",
            ["", "e", ", Invert"],
            ["", "e", ", Restrict Range"],
            ", Max Rounding Digits:",
            ", Output Variable Name:",
        ],
    },
    "39t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "ConditionList"],
        "display": "For",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            "Variable:",
            ", Items:",
            ["", "e", ", Structure Output (JSON, etc)"],
            ["if"],
            [""],
        ],
    },
    "3s": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "BT Connected",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ", Address:"],
    },
    "400t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Int"],
        "display": "Move",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["From:", ", To:", ["", "e", ", Use Root"]],
    },
    "402t": {
        "numargs": 0,
        "args": ["0"],
        "types": ["Bundle"],
        "display": "Get Clipboard",
    },
    "404t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Int"],
        "display": "Copy File",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["From:", ", To:", ["", "e", ", Use Root"]],
    },
    "405t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Int"],
        "display": "Copy Dir",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["From:", ", To:", ["", "e", ", Use Root"]],
    },
    "406t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "ConditionList"],
        "display": "Delete File",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ["", "e", ", Use Root"]],
    },
    "407t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "Pick Photos",
        "reqargs": ["1", "2", "3"],
        "evalargs": [",Max Number:", ", Mime Type:", ["", "e", ", Copy To Cache"]],
    },
    "40830242s": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoNotification Intercept",
        "reqargs": ["0", "3"],
        "evalargs": ["Configuration:", ["", "e", ", Structure Output (JSON (etc)"]],
    },
    "408t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Int", "Int"],
        "display": "Delete Directory",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Directory:", ["", "e", ", Recurse"], ["", "e", ", Use Root"]],
    },
    "409t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "ConditionList"],
        "display": "Create Directory",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Directory:", ["", "e", ", Create All"], ["", "e", ", Use Root"]],
    },
    "40s": {
        "numargs": 0,
        "args": 0,
        "types": [],
        "display": "Call",
        "reqargs": ["0", "1"],
        "evalargs": ["Type:", ", Number:"],
    },
    "40t": {"numargs": 0, "args": [], "types": [], "display": "End For"},
    "410t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Str", "Int", "Int", "ConditionList"],
        "display": "Write File",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "File:",
            ", Text:",
            ["", "e", ", Append"],
            ["", "e", ", Add New Line"],
        ],
    },
    "411e": {"numargs": 0, "args": [], "types": [], "display": "Device Boot"},
    "412t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Str", "Int"],
        "display": "List Files",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Directory:",
            ", Match:",
            ["", "e", ", Include Hidden Files"],
            ["", "e", ", Use Root"],
            [", Sort Selection:", "l", "412"],
            ", Variable Array:",
        ],
    },
    "413t": {
        "numargs": 3,
        "args": ["1", "2", "3"],
        "types": ["Str", "Str", "Str"],
        "display": "Request Add Tile",
        "reqargs": ["1", "2", "3"],
        "evalargs": ["Tile To Add:", "Title:", "Icon:"],
    },
    "413e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Device Shutdown",
        "reqargs": [],
        "evalargs": [],
    },
    "414549629t": {"redirect": ["1040876951t"], "display": "AutoSpotify Search"},
    "415t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Read Line",
        "reqargs": [],
        "evalargs": [],
    },
    "41628340e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoVoice Intercept",
        "reqargs": ["3"],
        "evalargs": [["", "e", ", Structure Output (JSON, etc)"]],
    },
    "416t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Str"],
        "display": "Read Paragraph",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["File:", ", Para:", ", To Var:"],
    },
    "417t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Read File",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["File:", ", To Var:", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "41t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Str", "Int", "Str", "Int"],
        "display": "Send SMS",
        "reqargs": ["0", "1", "3", "4"],
        "evalargs": [
            "Number:",
            ", Message:",
            ", SIM Card:",
            ["", "e", ", Wait For Result"],
        ],
    },
    "420t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Int", "Str"],
        "display": "Zip",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "File:",
            ["", "e", ", Delete Dialog"],
            ", Level:",
            ", Output File:",
        ],
    },
    "421t": {
        "numargs": 0,
        "args": ["0"],
        "types": ["Bundle"],
        "display": "Get Screen Info",
    },
    "422e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Device Storage Low",
        "reqargs": [],
        "evalargs": [],
    },
    "422t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "UnZip",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ["", "e", ", Delete Zip"]],
    },
    "424e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Screebl / TSC",
        "reqargs": [],
        "evalargs": [],
    },
    "424t": {
        "numargs": 0,
        "args": ["0"],
        "types": ["Bundle"],
        "display": "Get Battery Info",
    },
    "424867932t": {
        "redirect": ["1040876951t"],
        "display": "AutoBubbles Manage Bubble",
    },
    "425e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "K9 Email Received",
        "reqargs": [],
        "evalargs": [],
    },
    "425t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Wifi",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "426e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Widget Locker",
        "reqargs": [],
        "evalargs": [],
    },
    "426t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Wifi Net",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            ["Action:", "l", "426"],
            ["", "e", ", Force"],
            ["", "e", ", Report Failure"],
        ],
    },
    "427e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "OpenWatch",
        "reqargs": [],
        "evalargs": [],
    },
    "427t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Wifi Sleep",
        "reqargs": ["0"],
        "evalargs": [["Policy:", "l", "427"]],
    },
    "427019141t": {
        "redirect": ["1040876951t"],
        "display": "AutoNotification Replace Gmail Notifications",
    },
    "428e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Kaloer Clock",
        "reqargs": [],
        "evalargs": [],
    },
    "42924197t": {"redirect": ["1040876951t"], "display": "Notification Listener"},
    "429032033t": {"redirect": ["1040876951t"], "display": "AutoContacts Details"},
    "429e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Locale Changed",
        "reqargs": [],
        "evalargs": [],
    },
    "42t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Str"],
        "display": "Send Data SMS",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Number:", ", Port:", ", Data:", ["if", ""]],
    },
    "430t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Bundle", "Int", "ConditionList"],
        "display": "Restart Tasker",
        "reqargs": ["0"],
        "evalargs": [["", "e", ", Only Monitor"]],
    },
    "431t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Int", "Str", "Str", "ConditionList"],
        "display": "Accessibility Services",
        "reqargs": ["1", "2"],
        "evalargs": [["Action:", "l", "431"], ", Services"],
    },
    "433t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Bundle"],
        "display": "Mobile Data",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "438t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Bundle", "Str", "Str", "Str", "Str"],
        "display": "Matter Light",
        "reqargs": ["1", "2", "3", "4"],
        "evalargs": ["Device IDs/Name:", ", Set:", ", Color:", ", Brightness:"],
    },
    "439t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "WiMax",
        "reqargs": [],
        "evalargs": [],
    },
    "43t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["ConditionList"],
        "display": "Else/Else If",
        "reqargs": ["if"],
        "evalargs": [""],
    },
    "432t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Get Network Info",
        "reqargs": [],
        "evalargs": [],
    },
    "440t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Set Timezone",
        "reqargs": [],
        "evalargs": [],
    },
    "441t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Bundle"],
        "display": "Work Profile",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "442t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "SleepBot",
        "reqargs": [],
        "evalargs": [],
    },
    "443t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "App", "Int"],
        "display": "Media Control",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            ["Cmd:", "l", "443"],
            ["", "e", ", Simulate Media Button"],
            ", Package/App Name:",
            ["", "e", ", Use Notification If Available"],
        ],
    },
    "444e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Pomodroido",
        "reqargs": [],
        "evalargs": [],
    },
    "444t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "TeslaLED",
        "reqargs": [],
        "evalargs": [],
    },
    "445e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Radardroid",
        "reqargs": [],
        "evalargs": [],
    },
    "445t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Music Play",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            "File:",
            ", Start:",
            ["", "e", ", Loop"],
            ["Cmd:", "l", "171"],
            ["", "e", ", Continue Task Immediately"],
        ],
    },
    "446e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Gentle Alarm",
        "reqargs": [],
        "evalargs": [],
    },
    "447e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Reddit Notify",
        "reqargs": [],
        "evalargs": [],
    },
    "447t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Int", "Int", "Int", "Int", "Int"],
        "display": "Music Play Dir",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Directory:",
            ["", "e", ", Subdirs"],
            ["", "e", ", Audio Only"],
            ["", "e", ", Random"],
            ["", "e", ", Flash"],
            ", Maximum Tracks:",
        ],
    },
    "448e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Notify My Android",
        "reqargs": [],
        "evalargs": [],
    },
    "449t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Music Stop",
        "reqargs": ["0"],
        "evalargs": [["", "e", ", Clear Dir"]],
    },
    "450e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "New Package",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ", Package:"],
    },
    "450t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "APN Droid",
        "reqargs": [],
        "evalargs": [],
    },
    "451e": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Package Removed",
        "reqargs": ["0"],
        "evalargs": ["Package:"],
    },
    "451t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Music Skip",
        "reqargs": ["0"],
        "evalargs": ["Jump:"],
    },
    "453e": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Package Updated",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ", Package:"],
    },
    "453t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Music Back",
        "reqargs": ["0"],
        "evalargs": ["Jump:"],
    },
    "455t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "Int"],
        "display": "Record Audio",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "File:",
            [", Source:", "l", "455"],
            ", MaxSize:",
            [", Format:", "l", "455a"],
        ],
    },
    "456t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "JD APN",
        "reqargs": [],
        "evalargs": [],
    },
    "457t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Default Ringtone",
        "reqargs": [],
        "evalargs": [],
    },
    "458t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "WidgetLocker",
        "reqargs": [],
        "evalargs": [],
    },
    "459t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Scan Media",
        "reqargs": ["0"],
        "evalargs": ["File:"],
    },
    "460e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Wallpaper Changed",
        "reqargs": [],
        "evalargs": [],
    },
    "461e": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["App", "Str", "Str", "Str", "Str", "Str", "Str", "Int"],
        "display": "Notification",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Owner Application:",
            ", Title:",
            ", Text:",
            ", Subtext:",
            ", Messages:",
            ", Other Text:",
            ", Cat:",
            ["", "e", ", New Only"],
        ],
    },
    "461t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Scan Media",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Owner Application:",
            ", Title:",
            ", Text:",
            ", Subtext:",
            ", Messages:",
            ", Other Text:",
            ", Cat:",
            ["", "e", ", New Only"],
        ],
    },
    "462e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Button Widget Clicked",
        "reqargs": [],
        "evalargs": [],
    },
    "463e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "New Window",
        "reqargs": [],
        "evalargs": [],
    },
    "464e": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["App", "Str", "Str", "Str", "Str", "Str"],
        "display": "Notification Removal",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Owner Application:",
            ", Title:",
            ", Text:",
            ", Subtext:",
            ", Messages:",
            ", Other Text:",
        ],
    },
    "46t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Create Scene",
        "reqargs": ["0"],
        "evalargs": ["Name:"],
    },
    "475t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "GZip",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ["", "e", ", Delete Orig"]],
    },
    "476t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "GUnzip",
        "reqargs": ["0", "1"],
        "evalargs": ["File:", ["", "e", ", Delete Zip"]],
    },
    "47t": {
        "numargs": 12,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        "types": [
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "display": "Show Scene",
        "reqargs": ["0", "1", "6", "7", "8", "9", "if"],
        "evalargs": [
            "Name:",
            ["Display As:", "l", "47"],
            ["", "e", "Show Exit Button"],
            ["", "e", "Continue Task Immediately"],
            ["", "e", "Allow Outside Boundaries"],
            ["", "e", "Blocking Overlay +"],
            [""],
        ],
    },
    "48t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "ConditionList"],
        "display": "Hide Scene",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", ["Animation:", "l", "48"]],
    },
    "490t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Media Button Events",
        "reqargs": ["0", "1"],
        "evalargs": [["File:", "l", "490"], ["", "e", ", Use New API"]],
    },
    "49t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "ConditionList"],
        "display": "Destroy Scene",
        "reqargs": ["0"],
        "evalargs": ["Name:"],
    },
    "4e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Phone Idle",
        "reqargs": [],
        "evalargs": [],
    },
    "502102143t": {
        "redirect": ["1040876951t"],
        "display": "AutoSheets Get Spreadsheet",
    },
    "4s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Phone Idle",
        "reqargs": ["0"],
        "evalargs": [["Priority:", "l", "4s"]],
    },
    "502807688t": {"redirect": ["1040876951t"], "display": "AutoAppsHub SendCommand"},
    "50s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Keyboard Out",
        "reqargs": [],
        "evalargs": [],
    },
    "50t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "ConditionList"],
        "display": "Element Value",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", ", Value:"],
    },
    "511t": {
        "numargs": 1,
        "args": ["0", "1"],
        "types": ["Int", "Str"],
        "display": "Torch",
        "reqargs": ["0"],
        "evalargs": [["File:", "l", "switch_set"]],
    },
    "512t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "ConditionList"],
        "display": "Status Bar",
        "reqargs": ["0"],
        "evalargs": [["File:", "l", "512"]],
    },
    "513t": {"numargs": 0, "args": [], "types": [], "display": "Close System Dialogs"},
    "51t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Str", "Int", "Str", "Str", "ConditionList"],
        "display": "Element Text",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            "Scene Name:",
            ", Element:",
            [", Position:", "l", "51"],
            ", Text:",
            ", Selection:",
        ],
    },
    "523t": {
        "numargs": 13,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12"],
        "types": [
            "Str",
            "Str",
            "Img",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "ConditionList",
        ],
        "display": "Notify",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10", "11"],
        "evalargs": [
            "Title:",
            ", Text:",
            ", Icon:",
            "",
            ["", "e", ", Permanent"],
            ", Priority:",
            ["", "e", ", Repeat Alert"],
            [", LED Color:", "l", "523"],
            ", LED Rate:",
            ", Sound File:",
            ", Vibration Pattern:",
            ", Cat:",
            "Actions:",
        ],
    },
    "525t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Str", "Img", "Int", "Int", "Int", "Int", "Int"],
        "display": "Notify LED",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            ":Title:",
            ", Text:",
            ", Icon:",
            "",
            [", LED Color:", "l", "523"],
            ", Rate:",
            ", Priority:",
            ["", "e", ", Repeat Alert"],
        ],
    },
    "536t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Str", "Str", "Img", "Int", "Str", "Int", "Int"],
        "display": "Notify Vibrate",
        "reqargs": ["0", "1", "2", "4", "5", "6"],
        "evalargs": [
            "Title:",
            ", Text:",
            ", Icon:",
            ", Pattern:",
            ", Priority:",
            ["", "e", ", Repeat Alert"],
        ],
    },
    "538t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Str", "Str", "Img", "Int", "Str", "Int", "Int"],
        "display": "Notification Sound",
        "reqargs": ["0", "1", "2", "4", "5"],
        "evalargs": [
            "Title:",
            ", Text:",
            ", Icon:",
            ", Sound File:",
            ", Priority:",
            ["", "e", ", Repeat Alert"],
        ],
    },
    "53t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Str"],
        "display": "Element Web Control",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", [", Mode:", "l", "53"]],
    },
    "543t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Int"],
        "display": "Start System Timer",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Seconds:", ", Message:", ["", "e", ", Show UI"]],
    },
    "544t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Timer Widget Control",
        "reqargs": ["0", "1"],
        "evalargs": ["Name:", [", Type:", "l", "544"]],
    },
    "545t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Int"],
        "display": "Variable Randomize",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Name:", ", Min:", ", Max:"],
    },
    "546t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "Int"],
        "display": "Timer Widget Set",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": ["Name:", ", Seconds:", ", Minutes:", ", Hours:", ", Days:"],
    },
    "547e": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "unmapped",
        "reqargs": [],
        "evalargs": [],
    },
    "547t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Int", "Int", "ConditionList"],
        "display": "Variable Set",
        "reqargs": ["0", "1", "2", "4", "5", "6"],
        "evalargs": [
            "Name:",
            ", To:",
            ["", "e", ", Recursive Variables"],
            ["", "e", ", Do Maths"],
            ["", "e", ", Append"],
            ", Max Rounding Digits:",
            ["", "e", ", Structure Output (JSON, etc)"],
        ],
    },
    "548t": {
        "numargs": 16,
        "args": [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
            "15",
        ],
        "types": [
            "Str",
            "Int",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "Str",
            "Int",
            "Int",
            "Str",
            "Int",
            "ConditionList",
        ],
        "display": "Flash",
        "reqargs": [
            "0",
            "1",
            "2",
            "3",
            "4",
            "5",
            "6",
            "7",
            "8",
            "9",
            "10",
            "11",
            "12",
            "13",
            "14",
        ],
        "evalargs": [
            "Text:",
            ["", "e", ", Long"],
            ["", "e", ", Tasker Layout"],
            ", Title:",
            ", Icon:",
            " Icon Size:",
            ", Background Color:",
            ", Task:",
            ", Timeout:",
            ["", "e", ", Continue Task Immediately"],
            ", Text Color:",
            ["", "e", ", Dismiss On Click"],
            ["", "e", ", Show Over Everything"],
            ", Position:",
            ["", "e", ", Use HTML"],
        ],
    },
    "549t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "ConditionList"],
        "display": "Variable Clear",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            "Name:",
            ["", "e", ", Pattern Matching"],
            ["", "e", ", Clear All Variables"],
        ],
    },
    "54t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Str"],
        "display": "Element Text Color",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", " Colour:"],
    },
    "550t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Str", "Str", "Str", "Int", "Int"],
        "display": "Popup",
        "reqargs": ["0", "1", "2", "4", "5"],
        "evalargs": [
            "Title:",
            ", Text:",
            ", Background Image:",
            ", Layout:",
            ", Timeout (Seconds):",
            ["", "e", ", Show Over Keyguard"],
        ],
    },
    "551t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Menu",
        "reqargs": [],
        "evalargs": [],
    },
    "552t": {
        "numargs": 9,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "types": ["Str", "Int", "Str", "Str", "Str", "Str", "Str", "Int", "Int"],
        "display": "Popup Task Buttons",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "evalargs": [
            "Text:",
            [", Mode:", "l", "552"],
            ", Task:",
            ", Task:",
            ", Task:",
            ", Background Image:",
            ", Layout:",
            ", Timeout (Seconds):",
            ["", "e", ", Show Over Keyguard"],
        ],
    },
    "553t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "SMS Backup+",
        "reqargs": [],
        "evalargs": [],
    },
    "555t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "BeyondPod",
        "reqargs": [],
        "evalargs": [],
    },
    "556t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "GrazeRSS",
        "reqargs": [],
        "evalargs": [],
    },
    "557649458t": {"redirect": ["1040876951t"], "display": "AutoWear Time"},
    "558t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Android Notifier",
        "reqargs": [],
        "evalargs": [],
    },
    "559t": {
        "numargs": 9,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "types": [
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "Int",
            "ConditionList",
        ],
        "display": "Say",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Text:",
            ", Engine Voice:",
            [", Stream", "l", "171"],
            ", Pitch:",
            ", Speed:",
            ["", "e", ", Respect Audio Focus"],
            ["", "e", ", Network"],
            ["", "e", ", Continue Task Immediately"],
        ],
    },
    "55t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Str", "Str", "Str", "ConditionList"],
        "display": "Element Back Color",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["Scene Name:", ", Element:", " Colour:", " End Colour:"],
    },
    "563213414t": {"redirect": ["1040876951t"], "display": "AutoNotification Table"},
    "565385068t": {"redirect": ["1040876951t"], "display": "AutoNotification Query"},
    "566t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Int", "Int", "Str", "Str", "Int", "Int", "ConditionList"],
        "display": "Set Alarm",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Hours:",
            ", Minutes:",
            ", Label:",
            ", Sound:",
            [", Vibrate:", "l", "566"],
            ["", "e", ", Confirm"],
        ],
    },
    "567t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Str", "Str", "Str", "Str", "Int", "Int", "ConditionList"],
        "display": "Calendar Insert",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6"],
        "evalargs": [
            "In/For Minutes:",
            ", Calendar:",
            ", Title:",
            ", Description:",
            ", Location:",
            ["", "e", ", Available"],
            ["", "e", ", All Day"],
        ],
    },
    "568t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "DailyRoads Voyager",
        "reqargs": [],
        "evalargs": [],
    },
    "5683503e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoInput UI Action",
        "reqargs": ["0", "3"],
        "evalargs": ["", ["", "e", ", Structure Output (JSON, etc)"]],
    },
    "56t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Str"],
        "display": "Element Border",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["Scene Name:", ", Element:", ", Width:", ", Colour:"],
    },
    "57t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Int"],
        "display": "Element Size",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Scene Name:",
            ", Element:",
            [", Orientation:", "l", "57"],
            ", X:",
            ", Y:",
            ", Animation Time (MS):",
        ],
    },
    "570237327t": {"redirect": ["1040876951t"], "display": "AutoSheets Format Cells"},
    "580953799e": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Bundle", "Str", "Str", "Int"],
        "display": "AutoShare",
        "reqargs": ["3"],
        "evalargs": [["", "e", ", Structure Output (JSON, etc)"]],
    },
    "58t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Str", "Int", "Int", "Int", "Int"],
        "display": "Element Size",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Scene Name:",
            ", Element:",
            [", Orientation:", "l", "57"],
            ", Width:",
            ", Height:",
            ", Animation Time (MS):",
        ],
    },
    "590t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Str", "Int", "Int", "ConditionList"],
        "display": "Variable Split",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Name:",
            ", Splitter:",
            ["", "e", ", Delete Base"],
            ["", "e", ", Regex"],
        ],
    },
    "592t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Variable Join",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Name:", ", Joiner:", ["", "e", ", Delete Parts"]],
    },
    "595t": {
        "numargs": 8,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "types": ["Str", "Str", "Int", "Str", "Str", "Str", "Int", "Int"],
        "display": "Variable Query",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7"],
        "evalargs": [
            "Title:",
            ", Variable:",
            [", Input Type:", "l", "595"],
            ", Default:",
            ", Background Image:",
            ", Layout:",
            ", Timeout (Seconds):",
            ["", "e", ", Show Over Keyguard"],
        ],
    },
    "596t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Str", "Int"],
        "display": "Variable Convert",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Name:", [", Function:", "l", "596"], ", Store Result In:"],
    },
    "597t": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Int", "Str"],
        "display": "Variable Section",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            "Name:",
            ", From:",
            ", Length:",
            ["", "e", ", Adopt To Fit"],
            ", Store Result In:",
        ],
    },
    "598t": {
        "numargs": 9,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "types": [
            "Str",
            "Str",
            "Int",
            "Int",
            "Int",
            "Str",
            "Int",
            "Str",
            "ConditionList",
        ],
        "display": "Variable Search Replace",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6"],
        "evalargs": [
            "Variable:",
            ", Search:",
            ["", "e", ", Ignore Case"],
            ["", "e", ", Multi-Line"],
            ["", "e", ", One Match Only"],
            ", Show Matches In Array:",
            ["", "e", ", Replace Matches"],
        ],
    },
    "599e": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Str", "Int", "Int", "Str", "Str"],
        "display": "Intent Received",
        "reqargs": ["1", "2", "3", "4"],
        "evalargs": [
            "Action:",
            [", Cat:", "l", "877"],
            [", Cat:", "l", "877"],
            ", Schema:",
            ", Mime Type:",
            ", Priority:",
            ["", "e", ", Stop Event"],
        ],
    },
    "599t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Due Today",
        "reqargs": [],
        "evalargs": [],
    },
    "59t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Reboot",
        "reqargs": [],
        "evalargs": [],
    },
    "5s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Calendar Entry",
        "reqargs": [],
        "evalargs": [],
    },
    "60t": {
        "numargs": 9,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8"],
        "types": ["Str", "Str", "Str", "Str", "Str", "Int", "Int", "Str", "Img"],
        "display": "Element Add GeoMarker",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Scene Name:",
            ", Element:",
            ", Lat,Long:",
            ", Label:",
            ", Spot Radius (Meters):",
            ", Spot Color:",
        ],
    },
    "612t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Str"],
        "display": "Element Video Control",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Scene Name:",
            ", Element:",
            [", Mode:", "l", "612"],
            ", MilliSeconds:",
        ],
    },
    "61t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "ConditionList"],
        "display": "Vibrate",
        "reqargs": ["0"],
        "evalargs": ["Time:"],
    },
    "62t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "ConditionList"],
        "display": "Vibrate Pattern",
        "reqargs": ["0"],
        "evalargs": ["Pattern:"],
    },
    "63t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Str", "Str"],
        "display": "Element Delete GeoMarker",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["Scene Name:", ", Element:", " Lat,Long:", " Label:"],
    },
    "643t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "OfficeTalk",
        "reqargs": [],
        "evalargs": [],
    },
    "64t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Str"],
        "display": "Element Map Control",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", [", Mode:", "l", "64"]],
    },
    "657t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Record Audio Stop",
        "reqargs": [],
        "evalargs": [],
    },
    "65t": {
        "numargs": 6,
        "args": ["0", "1", "2", "3", "4", "5"],
        "types": ["Str", "Str", "Int", "Int", "Int", "ConditionList"],
        "display": "Element Visibility",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            "Scene Name:",
            ", Element Match:",
            [", Set:", "l", "65"],
            "Animation Time (MS):",
            ["", "e", ", Continue Task Immediately"],
        ],
    },
    "658527372t": {"redirect": ["1040876951t"], "display": "AutoTools HTML Read"},
    "664t": {
        "numargs": 10,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "types": ["Str", "Str", "Str", "Str", "Str", "Str", "Str", "Str", "Str", "Str"],
        "display": "Java Function",
        "reqargs": ["0", "1"],
        "evalargs": ["Class or Object:", ", Function:"],
    },
    "665t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Str"],
        "display": "Java Object",
        "reqargs": ["0", "1"],
        "evalargs": [["Mode:", "l", "665"], ", Name:"],
    },
    "667t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "SQL Query",
        "reqargs": [],
        "evalargs": [],
    },
    "66t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Img", "ConditionList"],
        "display": "Element Image",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", ", Image:"],
    },
    "67t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Element Depth",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", ", Set Depth:"],
    },
    "68t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Element Focus",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", ["", "e", ", Set"]],
    },
    "697t": {"numargs": 0, "args": [], "types": [], "display": "Shut Up"},
    "699t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Str", "Str", "Str", "Int", "Int", "Int", "Int"],
        "display": "Say To File",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6"],
        "evalargs": [
            "Text:",
            ", Engine/Voice:",
            ", File:",
            ", Pitch:",
            ", Speed:",
            ["", "e", ", Network"],
            ["", "e", ", Continue Task Immediately"],
        ],
    },
    "69t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Int", "Str"],
        "display": "Element Create",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Scene Name:",
            [", Set:", "l", "69"],
            ["", "e", ", Visible"],
            ", Content:",
        ],
    },
    "6e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Phone Ringing",
        "reqargs": [],
        "evalargs": [],
    },
    "6s": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Phone Ringing",
        "reqargs": ["0"],
        "evalargs": ["Contact:"],
    },
    "701t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Dpad",
        "reqargs": [],
        "evalargs": [],
    },
    "702t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Type",
        "reqargs": [],
        "evalargs": [],
    },
    "703953103t": {"redirect": ["1040876951t"], "display": "KLWP Live Wallpaper"},
    "703t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Button",
        "reqargs": [],
        "evalargs": [],
    },
    "71t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Element Text Size",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Scene Name:", ", Element:", ", Text Size:"],
    },
    "721t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Zoom Visibility",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ["", "e", ", Set"]],
    },
    "731t": {"numargs": 0, "args": [], "types": [], "display": "Take Call"},
    "732t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Radio",
        "reqargs": [],
        "evalargs": [],
    },
    "733t": {"numargs": 0, "args": ["0"], "types": ["Bundle"], "display": "End Call"},
    "734t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Silence Ringer",
        "reqargs": [],
        "evalargs": [],
    },
    "735t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Mobile Data 2G/3G",
        "reqargs": [],
        "evalargs": [],
    },
    "73t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Element Destroy",
        "reqargs": ["0", "1"],
        "evalargs": ["Scene Name:", ", Element:"],
    },
    "740t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Zoom Text",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ", Text:"],
    },
    "741t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Zoom Text Size",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ", Text Size:"],
    },
    "742t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Zoom Text Color",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ", Text Color:"],
    },
    "760t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Zoom Alpha",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ", Set:"],
    },
    "761t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Zoom Image",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ", URL:"],
    },
    "762t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Str"],
        "display": "Zoom Color",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Element:", ", Color:", ", End Color:"],
    },
    "774351906t": {"redirect": ["1040876951t"], "display": "Join Action"},
    "775t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Str"],
        "display": "Write Binary",
        "reqargs": ["0", "1"],
        "evalargs": ["Variable:", ", File:"],
    },
    "776t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Read Binary",
        "reqargs": [],
        "evalargs": [],
    },
    "778682267t": {"redirect": ["1040876951t"], "display": "AutoInput Gestures"},
    "779t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "ConditionList"],
        "display": "Notify Cancel",
        "reqargs": ["0"],
        "evalargs": ["Title:"],
    },
    "794294329t": {"redirect": ["1040876951t"], "display": "AutoSheets Add Sheet"},
    "793t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Zoom State",
        "reqargs": ["0", "1"],
        "evalargs": ["Element:", ", State:"],
    },
    "794t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Int", "Int"],
        "display": "Zoom Position",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": ["Element:", [", Orientation:", "l", "57"], ", X:", ", Y:"],
    },
    "795t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Int", "Int", "Int"],
        "display": "Zoom Size",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Element:",
            [", Orientation:", "l", "57"],
            ", Width:",
            ", Height:",
        ],
    },
    "7e": {
        "numargs": 5,
        "args": ["0", "1", "2", "3", "4"],
        "types": ["Int", "Str", "Str", "Str", "Str"],
        "display": "Received Text",
        "reqargs": ["0", "1", "2", "3", "4"],
        "evalargs": [
            ["Type:", "l", "7e"],
            ", Sender:",
            ", Content:",
            ", SIM Card:",
            ", MMS Body:",
        ],
    },
    "7s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Cell Near",
        "reqargs": [],
        "evalargs": [],
    },
    "801498676t": {"redirect": ["1040876951t"], "display": "AutoSpotify Albums"},
    "804t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Input Method Select",
        "reqargs": [],
        "evalargs": [],
    },
    "806t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Turn On",
        "reqargs": ["0"],
        "evalargs": ["Block Time:"],
    },
    "808t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Auto Brightness",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "80s": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Docked",
        "reqargs": [],
        "evalargs": [],
    },
    "810t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "Int"],
        "display": "Display Brightness",
        "reqargs": ["0", "1", "2"],
        "evalargs": [
            "Level:",
            ["", "e", ", Disable Safeguard"],
            ["", "e", ", Ignore Current Level"],
        ],
    },
    "811079103t": {"redirect": ["1040876951t"], "display": "AutoInput Global Action"},
    "812t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Int", "Int"],
        "display": "Display Timeout",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Secs:", ", Mins:", ", Hours:"],
    },
    "815t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Int", "Str", "Str"],
        "display": "List Apps",
        "reqargs": ["0", "1", "2"],
        "evalargs": [["Type:", "l", "815"], ", Match:", ", Store Result In:"],
    },
    "819222800t": {"redirect": ["1040876951t"], "display": "AutoSpotify Tracks"},
    "820t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Stay On",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "820"]],
    },
    "822t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Display Autorotate",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "switch_set"]],
    },
    "864692752t": {"redirect": ["1040876951t"], "display": "Join"},
    "8618362t": {"redirect": ["1040876951t"], "display": "AutoSpotify Notification"},
    "877t": {
        "numargs": 11,
        "args": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "10"],
        "types": [
            "Str",
            "Int",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Str",
            "Int",
            "ConditionList",
        ],
        "display": "Send Intent",
        "reqargs": ["0", "1", "2", "3", "4", "5", "6", "7", "8", "9"],
        "evalargs": [
            "Action:",
            [", Mode:", "l", "877"],
            ", Mime Type:",
            ", Data:",
            ", Extra:",
            ", Extra:",
            ", Extra:",
            ", Package:",
            ", Class:",
            [", Target:", "l", "877a"],
        ],
    },
    "888t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Int"],
        "display": "Variable Add",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Name:", ", Value:", ", Wrap Around:"],
    },
    "890t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Int"],
        "display": "Variable Subtract",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Name:", ", Value:", ", Wrap Around:"],
    },
    "8e": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Received Data SMS",
        "reqargs": [],
        "evalargs": [],
    },
    "900t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Browse Files",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Directory:", ", Match:", ["", "e", ", Include Hidden Files"]],
    },
    "901t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Stop Location",
        "reqargs": ["0"],
        "evalargs": [["Set:", "l", "901"]],
    },
    "902t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Int", "Int", "Int", "Int"],
        "display": "Get Location",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            ["Set:", "l", "901"],
            ", Timeout (Seconds):",
            ["", "e", ", Continue Task Immediately"],
            ["", "e", ", Keep Tracking"],
        ],
    },
    "903t": {
        "numargs": 7,
        "args": ["0", "1", "2", "3", "4", "5", "6"],
        "types": ["Str", "Int", "Str", "Int", "Int", "Int", "Bundle"],
        "display": "Get Voice",
        "reqargs": ["0", "1", "2", "3", "4", "5"],
        "evalargs": [
            "Title:",
            [", Mode:", "l", "903"],
            ", Language:",
            ", Maximum Results:",
            ", Timeout:",
            ["", "e", ", Hide Dialog"],
        ],
    },
    "904t": {"numargs": 0, "args": [], "types": [], "display": "Voice Command"},
    "905t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Location Mode",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "905"]],
    },
    "906355163t": {"redirect": ["1040876951t"], "display": "AutoWear Voice Screen"},
    "906t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Immersive Mode",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "906"]],
    },
    "907t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Str"],
        "display": "Status Bar Icons",
        "reqargs": ["0"],
        "evalargs": ["Icons To Hide:"],
    },
    "907418897t": {"redirect": ["1040876951t"], "display": "AutoTools Action Report"},
    "909t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Contacts",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "909"]],
    },
    "90t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Int", "Str"],
        "display": "Call",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["Number:", ["", "e", ", Auto Dial"], ", Sim Card:"],
    },
    "910t": {
        "numargs": 1,
        "args": ["0"],
        "types": ["Int"],
        "display": "Call Log",
        "reqargs": ["0"],
        "evalargs": [["Mode:", "l", "910"]],
    },
    "911t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Gentle Alarm",
        "reqargs": [],
        "evalargs": [],
    },
    "915t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "CPU",
        "reqargs": [],
        "evalargs": [],
    },
    "917310686t": {"redirect": ["1040876951t"], "display": "AutoSpotify Artists"},
    "918403287t": {
        "redirect": ["1040876951t"],
        "display": "AutoNotification Categories",
    },
    "921575593t": {"redirect": ["1040876951t"], "display": "AutoInput Keyguard"},
    "940160580t": {"redirect": ["1040876951t"], "display": "AutoShare"},
    "941t": {
        "numargs": 4,
        "args": ["0", "1", "2", "3"],
        "types": ["Str", "Str", "Int", "Int"],
        "display": "HTML Popup",
        "reqargs": ["0", "1", "2", "3"],
        "evalargs": [
            "Code:",
            ", Layout:",
            ", Timeout (Seconds)",
            ["", "e", ", Show Over Keyguard"],
        ],
    },
    "956t": {"numargs": 0, "args": [], "types": [], "display": "NFC Settings"},
    "957t": {"numargs": 0, "args": [], "types": [], "display": "Android Beam Settings"},
    "958t": {"numargs": 0, "args": [], "types": [], "display": "NFC Payment Settings"},
    "959t": {"numargs": 0, "args": [], "types": [], "display": "Dream Settings"},
    "95t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Call Block",
        "reqargs": ["0", "1"],
        "evalargs": ["Number Match:", ["", "e", "Info"]],
    },
    "96585332t": {"redirect": ["1040876951t"], "display": "AutoWear Settings"},
    "97t": {
        "numargs": 3,
        "args": ["0", "1", "2"],
        "types": ["Str", "Str", "Int"],
        "display": "Call Divert",
        "reqargs": ["0", "1", "2"],
        "evalargs": ["From Match:", ", To:", ["", "e", ", Info"]],
    },
    "985050481t": {"redirect": ["1040876951t"], "display": "Actions"},
    "987t": {"numargs": 0, "args": [], "types": [], "display": "Soft Keyboard"},
    "988t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Int", "Int"],
        "display": "Car Mode",
        "reqargs": ["0", "1"],
        "evalargs": [["Set:", "l", "switch_set"], ["", "e", ", Go Home"]],
    },
    "989t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Night Mode",
        "reqargs": [],
        "evalargs": [],
    },
    "999t": {
        "numargs": 0,
        "args": [],
        "types": [],
        "display": "Set Light",
        "reqargs": [],
        "evalargs": [],
    },
    "99t": {
        "numargs": 2,
        "args": ["0", "1"],
        "types": ["Str", "Int"],
        "display": "Call Revert",
        "reqargs": ["0", "1"],
        "evalargs": ["Number:", ["", "e", "Info"]],
    },
}
